@@ -1,31 +1,23 @@
 package WebService::Solr::Document;
 
-use WebService::Solr::Field;
-use XML::Easy::Element;
-use XML::Easy::Content;
-use XML::Easy::Text ();
-use Scalar::Util 'blessed';
+use Moose;
 
-sub new {
+use WebService::Solr::Field;
+require XML::Generator;
+
+has 'fields' => (
+    is         => 'rw',
+    isa        => 'ArrayRef[Object]',
+    default    => sub { [] },
+    auto_deref => 1
+);
+
+has 'boost' => ( is => 'rw', isa => 'Maybe[Num]' );
+
+sub BUILDARGS {
     my ( $class, @fields ) = @_;
 
-    my $self = {
-        fields => [ _parse_fields( @fields ) ]
-    };
-
-    return bless $self, $class;
-}
-
-sub boost {
-    my $self = shift;
-    $self->{ boost } = $_[ 0 ] if @_;
-    return $self->{ boost };
-}
-
-sub fields {
-    my $self = shift;
-    $self->{ fields } = $_[ 0 ] if @_;
-    return wantarray ? @{ $self->{ fields } } : $self->{ fields };
+    return { fields => [ _parse_fields( @fields ) ] };
 }
 
 sub add_fields {
@@ -49,30 +41,16 @@ sub _parse_fields {
         }
 
         my $v = shift @fields;
-        my @values = ( ref $v and !blessed $v ) ? @$v : $v;
-        push @new_fields,
-            map { WebService::Solr::Field->new( $f => "$_" ) } @values;
+        my @values = ( ref $v and !blessed $v )? @$v : ( "$v" );
+        push @new_fields, map { WebService::Solr::Field->new( $f => $_ ) } @values;
     }
 
     return @new_fields;
 }
 
-sub field_names {
-    my ( $self ) = @_;
-    my %names = map { $_->name => 1 } $self->fields;
-    return keys %names;
-}
-
 sub value_for {
-    my ( $self, $key ) = @_;
-
-    for my $field ( $self->fields ) {
-        if ( $field->name eq $key ) {
-            return $field->value;
-        }
-    }
-
-    return;
+    my @values = shift->values_for( shift );
+    return $values[ 0 ];
 }
 
 sub values_for {
@@ -80,23 +58,18 @@ sub values_for {
     return map { $_->value } grep { $_->name eq $key } $self->fields;
 }
 
-sub to_element {
-    my $self = shift;
-    my %attr = ( $self->boost ? ( boost => $self->boost ) : () );
-
-    my @elements = map { ( '' => $_->to_element ) } $self->fields;
-
-    return XML::Easy::Element->new( 'doc', \%attr,
-        XML::Easy::Content->new( [ @elements, '' ] ),
-    );
-}
-
 sub to_xml {
     my $self = shift;
+    my $gen  = XML::Generator->new( ':std' );
+    my %attr = ( $self->boost ? ( boost => $self->boost ) : () );
 
-    return XML::Easy::Text::xml10_write_element( $self->to_element );
+    return $gen->doc( \%attr, map { $_->to_xml } $self->fields );
 }
 
+no Moose;
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -134,7 +107,7 @@ a collection of fields.
 
 Constructs a new document object given C<@fields>. A field can be a
 L<WebService::Solr::Field> object, or a structure accepted by
-C<WebService::Solr::Field-E<gt>new>.
+C<WebService::Solr::Field->new>.
 
 =head2 BUILDARGS( @args )
 
@@ -144,10 +117,6 @@ A Moose override to allow our custom constructor.
 
 Adds C<@fields> to the document.
 
-=head2 field_names
-
-Returns a list of field names that are in this document.
-
 =head2 value_for( $name )
 
 Returns the first value for C<$name>.
@@ -156,10 +125,6 @@ Returns the first value for C<$name>.
 
 Returns all values for C<$name>.
 
-=head2 to_element( )
-
-Serializes the object to an XML::Easy::Element object.
-
 =head2 to_xml( )
 
 Serializes the object to xml.
@@ -168,14 +133,14 @@ Serializes the object to xml.
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
-Kirk Beers
+Kirk Beers E<lt>kirk.beers@nald.caE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2016 National Adult Literacy Database
+Copyright 2008 National Adult Literacy Database
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
 
