@@ -1,60 +1,34 @@
 package WebService::Solr::Field;
 
-use XML::Easy::Element;
-use XML::Easy::Content;
-use XML::Easy::Text ();
+use Moose;
 
-sub new {
-    my ( $class, $name, $value, $opts ) = @_;
+has 'name' => ( is => 'rw', isa => 'Str' );
+
+has 'value' => ( is => 'rw', isa => 'Str' );
+
+has 'boost' => ( is => 'rw', isa => 'Maybe[Num]' );
+
+require XML::Generator;
+
+sub BUILDARGS {
+    my ( $self, $name, $value, $opts ) = @_;
     $opts ||= {};
 
-    die "name required"  unless defined $name;
-    die "value required" unless defined $value;
-
-    my $self = {
-        name  => $name,
-        value => $value,
-        %{ $opts },
-    };
-
-    return bless $self, $class;
-}
-
-sub name {
-    my $self = shift;
-    $self->{ name } = $_[ 0 ] if @_;
-    return $self->{ name };
-}
-
-sub value {
-    my $self = shift;
-    $self->{ value } = $_[ 0 ] if @_;
-    return $self->{ value };
-}
-
-sub boost {
-    my $self = shift;
-    $self->{ boost } = $_[ 0 ] if @_;
-    return $self->{ boost };
-}
-
-sub to_element {
-    my $self = shift;
-    my %attr = ( $self->boost ? ( boost => $self->boost ) : () );
-
-    return XML::Easy::Element->new(
-        'field',
-        { name => $self->name, %attr },
-        XML::Easy::Content->new( [ $self->value ] ),
-    );
+    return { name => $name, value => $value, %$opts };
 }
 
 sub to_xml {
     my $self = shift;
+    my $gen  = XML::Generator->new( ':std' );
+    my %attr = ( $self->boost ? ( boost => $self->boost ) : () );
 
-    return XML::Easy::Text::xml10_write_element( $self->to_element );
+    return $gen->field( { name => $self->name, %attr }, $self->value );
 }
 
+no Moose;
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -93,11 +67,7 @@ Creates a new field object. Currently, the only option available is a
 
 =head2 BUILDARGS( @args )
 
-A Moo override to allow our custom constructor.
-
-=head2 to_element( )
-
-Serializes the object to an XML::Easy::Element object.
+A Moose override to allow our custom constructor.
 
 =head2 to_xml( )
 
@@ -107,14 +77,14 @@ Serializes the object to xml.
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
-Kirk Beers
+Kirk Beers E<lt>kirk.beers@nald.caE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2016 National Adult Literacy Database
+Copyright 2008 National Adult Literacy Database
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
 
